@@ -6,10 +6,6 @@
 """Module for configuring machine learning models"""
 from dataclasses import dataclass
 
-__author__ = "Thilo Bauer"
-__license__ = "Open Logistics License 1.0"
-__email__ = "thilo.bauer@dbschenker.com"
-
 
 @dataclass
 class Configuration:
