@@ -25,9 +25,9 @@ class AnnotationWriter:
 
         Args:
             annotations: list of annotations that should be written
-            output_file_path: path to file, where the annotations should be written to
 
-        Returns: None
+        Returns:
+            Optionally path of written file
 
         """
         raise NotImplementedError()
