@@ -89,10 +89,10 @@ class Model(ABC, Generic[PredictionType, ConfigurationType, DataType]):
             from_yaml: (Optional) Parse the configuration from this file path
             configuration: (Optional) When provided this configuration object is passed-trough.
                            It is leveraged as a convenience option.
-            string_replacement_map: A dictionary that defines placeholders which can be used
-                                    while parsing the file. They can be understood as variables
-                                    that can be used to define configs that are valid across
-                                    multiple devices.
+            string_replacement_map: (Optional) A dictionary that defines placeholders which can
+                                    be used while parsing the file. They can be understood as
+                                    variables that can be used to define configs that are valid
+                                    across multiple devices.
 
         Returns:
             The created configuration object for this model
@@ -321,6 +321,7 @@ class SegmentationModel(Model[Segmentation, ConfigurationType, DataType], Classi
         return segmentations
 
 
+# TODO: Rename to TextRecognitionModel?
 class OCRModel(Model[OCRPerception, ConfigurationType, DataType]):
     """
     Class that declares the generic method predict(...) for all models that are
