@@ -9,7 +9,7 @@ import os
 import sys
 import time
 from argparse import ArgumentTypeError
-from typing import Any, Dict, Optional, Tuple, Type, Union, cast
+from typing import Dict, Optional, Tuple, Type, Union, cast
 
 import yaml
 from config_builder import BaseConfigClass, ConfigBuilder
@@ -161,7 +161,6 @@ def create_configuration(
     Returns:
         The created configuration object
     """
-    configuration: BaseConfigClass
 
     logger.info(
         f"\n==========================================\n"
@@ -172,13 +171,14 @@ def create_configuration(
         f"=========================================="
     )
 
-    configuration = ConfigBuilder(
-        class_type=configuration_class,
-        yaml_config_path=from_yaml,
-        configuration=input_configuration,
-        string_replacement_map=string_replacement_map,
-        mutual_attribute_map={},
-    ).configuration
+    if not input_configuration:
+        configuration: BaseConfigClass = ConfigBuilder(
+            class_type=configuration_class,
+            yaml_config_path=from_yaml,
+            string_replacement_map=string_replacement_map,
+        ).configuration
+    else:
+        configuration = input_configuration
 
     configuration_vars = vars(configuration)
 
@@ -199,13 +199,26 @@ def create_configuration(
 def handle_value_error_for_tool_configuration(
     value_error: ValueError, config_builder_instance: ConfigBuilder
 ) -> None:
+    """
+    DEPRECATED
+
+    Args:
+        value_error:
+        config_builder_instance:
+
+    Returns:
+
+    """
 
     logger.warning(str(value_error))
     for logger_handler in logger.root.handlers:
         logger_handler.flush()
     time.sleep(0.1)
 
-    config_builder_instance.parser.print_help(sys.stdout)
+    logger.warning(
+        "(DEPRECATED) The method handle_value_error_for_tool_configuration(...) "
+        "is deprecated and will be removed in future versions"
+    )
 
 
 def write_config_to_yaml(config: BaseConfigClass, output_yaml_config_path: str) -> None:
