@@ -99,9 +99,9 @@ class PascalVOCAnnotationBuilder(AnnotationBuilder):
 
         root = tree.getroot()
 
-        width = int(root.find("size")[1].text)  # type: ignore
-        height = int(root.find("size")[0].text)  # type: ignore
-        image_shape = (width, height)
+        width = int(root.find("size").find("width").text)  # type: ignore
+        height = int(root.find("size").find("height").text)  # type: ignore
+        image_shape = (height, width)
 
         source_image_filename = ""
         if root.find("path") is not None:
