@@ -100,7 +100,7 @@ class MOTAnnotationParser(AnnotationParser):
                 if frame_id not in annotation_line_dict:
                     annotation_line_dict[frame_id] = []
 
-                annotation_line_dict[frame_id].append(annotation_line)
+                annotation_line_dict[frame_id].append(annotation_line.strip())
 
             image_paths = get_file_list(
                 input_dir=input_data.image_dir,
