@@ -68,7 +68,7 @@ class ReadFromFileModel(
 
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[ReadFromFileConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
     ):
@@ -80,7 +80,7 @@ class ReadFromFileModel(
         )
         Model.__init__(
             self,
-            unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
+            unique_name=self.configuration.base_config.MODEL_SPECIFIER,
             configuration=self.configuration,
             init_for_inference=True,
         )
@@ -184,9 +184,10 @@ class ReadFromFileClassificationModel(
 ):
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[ReadFromFileConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
+        init_for_inference: bool = False,
     ):
         ReadFromFileModel.__init__(
             self,
@@ -196,7 +197,7 @@ class ReadFromFileClassificationModel(
         )
         ClassificationModel.__init__(
             self,
-            unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
+            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
@@ -223,9 +224,10 @@ class ReadFromFileObjectDetectionModel(
 ):
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[ReadFromFileConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
+        init_for_inference: bool = False,
     ):
         ReadFromFileModel.__init__(
             self,
@@ -235,7 +237,7 @@ class ReadFromFileObjectDetectionModel(
         )
         ObjectDetectionModel.__init__(
             self,
-            unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
+            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
@@ -267,9 +269,10 @@ class ReadFromFileSegmentationModel(
 ):
     def __init__(
         self,
-        from_yaml: str,
+        from_yaml: Optional[str] = None,
         configuration: Optional[ReadFromFileConfig] = None,
         string_replacement_map: Optional[Dict[str, str]] = None,
+        init_for_inference: bool = False,
     ):
         ReadFromFileModel.__init__(
             self,
@@ -279,7 +282,7 @@ class ReadFromFileSegmentationModel(
         )
         SegmentationModel.__init__(
             self,
-            unique_name=os.path.basename(from_yaml).replace(".yaml", ""),
+            unique_name=self.get_name(),
             configuration=self.configuration,
             mapper=self.mapper,
             init_for_inference=True,
